.. _exercises:

---------
Exercises
---------

Exercise 2 contains a script which takes somewhat long time.  For this
reason you may want to submit the script to Niflheim in advance,
before analyzing the results in Exercise 1.

.. toctree::
   :maxdepth: 2

   siesta1/siesta1
   siesta2/siesta2
